; Copyright 2019-2021 Sean Porter (Glitchfinder)
;
; Permission is hereby granted, free of charge, to any person obtaining a copy
; of this software and associated documentation files (the "Software"), to deal
; in the Software without restriction, including without limitation the rights
; to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
; copies of the Software, and to permit persons to whom the Software is
; furnished to do so, subject to the following conditions:
;
; The above copyright notice and this permission notice shall be included in all
; copies or substantial portions of the Software.
;
; THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
; IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
; FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
; AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
; LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
; OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
; SOFTWARE.
;------------------------------------------------------------------------------/

Scriptname zYAWA_Region_RR Extends ObjectReference

; All settlements and patrol points within this region
zYAWA_Settlement_RR[]  Property Settlements  Auto Hidden

; The number of members within a patrol spawned by this region
Int Property Size    = 3 Auto Hidden
Int Property OldSize = 3 Auto Hidden

; Do patrols within this region spawn eyebots?
Bool Property Eyebot    = False Auto Hidden
Bool Property OldEyebot = False Auto Hidden

; Do patrols within this region spawn robots?
Bool Property Robot    = False Auto Hidden
Bool Property OldRobot = False Auto Hidden

; Has this region been updated?
Bool Property Updated = True Auto Hidden

;------------------------------------------------------------------------------\
; Required settlement productivity for patrols within this region
;------------------------------------------------------------------------------|
;    Productivity is calculated as the sum of a settlement's food and water
;    production, combined with the settlement's total defense value. When two
;    settlements have different productivities due to being in separate regions,
;    the lower productivity will be used.
;------------------------------------------------------------------------------|
;  0 - None              (No production necessary)
;  1 - Village           (Settlements must have at least 10 productivity)
;  2 - Town              (Settlements must have at least 40 productivity)
;  3 - City              (Settlements must have at least 80 productivity)
;  4 - Industrial Center (Settlements must have at least 200 productivity)
;==============================================================================/
Int Property Productivity    = 1 Auto Hidden
Int Property OldProductivity = 1 Auto Hidden

;------------------------------------------------------------------------------\
; Density of patrols within this region
;------------------------------------------------------------------------------|
;    Map width is based on the northwest and southeast corners of the
;    commonwealth, which are at (-106,496 , 106,496) and (106,496 , -106,496),
;    respectively. This denotes a map width of 52 cells, or 212,992 units. Of
;    course, this width excludes the extensions to the map for the Glowing Sea,
;    the Nuka World Transit Center, and the Nakano House.
;
;    The distance is calculated as a simple square rather than using the
;    distance formula, to conserve processing power. When two settlements have
;    different densities due to being in seperate regions, the higher density
;    will be used.
;------------------------------------------------------------------------------|
;  0 - None         (No patrols from these settlements)
;  1 - Light        (Settlements within 1/4 of the map's width)
;  2 - Medium       (Settlements within 1/3 of the map's width)
;  3 - Heavy        (Settlements within 1/2 of the map's width)
;  4 - Overwhelming (All available setlements, including other regions)
;==============================================================================/
Int Property Density    = 3 Auto Hidden
Int Property OldDensity = 3 Auto Hidden

;------------------------------------------------------------------------------\
; Initialize this region
;------------------------------------------------------------------------------/
Function Initialize()
	; Initialize an empty array of settlements
	Settlements  = New zYAWA_Settlement_RR[128]

	; Default the size of patrols to 3 members
	Size = 3
EndFunction

;------------------------------------------------------------------------------\
; Update this region
;------------------------------------------------------------------------------/
Function Update()
	; If the size has changed
	If (Size != OldSize)
		; Cache the update and mark this region as updated
		OldSize = Size
		Updated = True
	EndIf

	; If the productivity has changed
	If (Productivity != OldProductivity)
		; Cache the update and mark this region as updated
		OldProductivity = Productivity
		Updated = True
	EndIf

	; If the eyebot setting has changed
	If (Eyebot != OldEyebot)
		; Cache the update and mark this region as updated
		OldEyebot = Eyebot
		Updated = True
	EndIf

	; If the robot setting has changed
	If (Robot != OldRobot)
		; Cache the update and mark this region as updated
		OldRobot = Robot
		Updated = True
	EndIf

	; If the density has changed
	If (Density != OldDensity)
		; Cache the update and mark this region as updated
		OldDensity = Density
		Updated = True
	EndIf
EndFunction
